@@ -2,11 +2,12 @@ package Business::Stripe::Subscription;
 
 use HTTP::Tiny;
 use JSON::PP;
+use Data::Dumper;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.1_1';
+our $VERSION = '1.0';
 $VERSION = eval $VERSION;
 
 my $http = HTTP::Tiny->new;
@@ -27,9 +28,9 @@ sub new {
     # This is changed during testing only
     $attrs{'url'}         //= 'https://api.stripe.com/v1/';
 
-    $attrs{'error'} = 'Secret API key provided as Public key' if $attrs{'api_public'} and $attrs{'api_public'} =~ /^sk_/;
+    $attrs{'error'} = 'Secret API key provided as Public key' if $attrs{'api_public'} =~ /^sk_/;
     $attrs{'error'} = 'Public API key provided as Secret key' if $attrs{'api_secret'} =~ /^pk_/;
-    $attrs{'error'} = 'Public API key provided is not a valid key' unless $attrs{'api_public'} and $attrs{'api_public'} =~ /^pk_/;
+    $attrs{'error'} = 'Public API key provided is not a valid key' unless $attrs{'api_public'} =~ /^pk_/;
     $attrs{'error'} = 'Secret API key provided is not a valid key' unless $attrs{'api_secret'} =~ /^sk_/;
     $attrs{'error'} = 'Secret API key is missing' unless $attrs{'api_secret'};
     $attrs{'error'} = 'Public API key is missing' unless $attrs{'api_public'};
@@ -284,6 +285,10 @@ __END__
 =head1 NAME
  
 L<Business::Stripe::Subscription> - Simple way to implement subscriptions using Stripe hosted checkout
+
+=head1
+
+Version 1.0
  
 =head1 SYNOPSIS
  
